@@ -141,7 +141,7 @@ e_address_western_is_po_box (gchar *line)
   deemed to be the line in the form of <town, region postal-code>. */
 
 static gboolean
-e_address_western_is_postal (guchar *line)
+e_address_western_is_postal (gchar *line)
 {
 	gboolean retval;
 	int cntr;
@@ -362,7 +362,10 @@ e_address_western_parse (const gchar *in_address)
 	/* Convert the newlines at the end of each line (except the last,
 	 because it is already NULL terminated) to NULLs. */
 	for (cntr = 0; cntr < (linecntr - 1); cntr++) {
-		*(strchr (lines[cntr], '\n')) = '\0';
+		char *p;
+		p = strchr (lines[cntr], '\n');
+		if (p)
+			*p = '\0';
 	}
 
 	e_address_western_remove_blank_lines (lines, &linecntr);
