@@ -7,15 +7,15 @@
  *          Rodrigo Moya <rodrigo@novell.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
@@ -97,6 +97,7 @@ typedef char * (* ECalAuthFunc) (ECal *ecal,
 GType e_cal_get_type (void);
 
 GType e_cal_open_status_enum_get_type (void);
+GType e_cal_source_type_enum_get_type (void);
 GType e_cal_set_mode_status_enum_get_type (void);
 GType cal_mode_enum_get_type (void);
 
@@ -104,6 +105,7 @@ ECal *e_cal_new (ESource *source, ECalSourceType type);
 ECal *e_cal_new_from_uri (const gchar *uri, ECalSourceType type);
 ECal *e_cal_new_system_calendar (void);
 ECal *e_cal_new_system_tasks (void);
+ECal *e_cal_new_system_memos (void);
 
 void e_cal_set_auth_func (ECal *ecal, ECalAuthFunc func, gpointer data);
 
@@ -165,7 +167,7 @@ GSList *e_cal_get_alarms_in_range (ECal *ecal, time_t start, time_t end);
 
 void e_cal_free_alarms (GSList *comp_alarms);
 
-gboolean e_cal_get_alarms_for_object (ECal *ecal, const char *uid,
+gboolean e_cal_get_alarms_for_object (ECal *ecal, const ECalComponentId *id,
 				      time_t start, time_t end,
 				      ECalComponentAlarms **alarms);
 
@@ -204,6 +206,8 @@ gboolean    e_cal_set_default (ECal  *ecal, GError **error);
 gboolean    e_cal_set_default_source (ESource *source, ECalSourceType type, GError **error);
 gboolean    e_cal_get_sources (ESourceList **sources, ECalSourceType type, GError **error);
 const char * e_cal_get_local_attachment_store (ECal *ecal);
+gboolean e_cal_get_recurrences_no_master (ECal *ecal);
+gboolean e_cal_get_attachments_for_comp (ECal *ecal, const char *uid, const char *rid, GSList **list, GError **error);
 
 G_END_DECLS
 
