@@ -3,8 +3,8 @@
   FILE: icalparser.c
   CREATOR: eric 04 August 1999
   
-  $Id: icalparser.c,v 1.18 2004/05/13 03:54:39 zucchi Exp $
-  $Locker:  $
+  $Id: icalparser.c 534 2005-09-30 14:25:35Z pchen $
+  $Locker$
     
  The contents of this file are subject to the Mozilla Public License
  Version 1.0 (the "License"); you may not use this file except in
@@ -106,6 +106,18 @@ struct icalparser_impl
 };
 
 
+char* strstrip (char *str)
+{
+	if (!str)
+		return NULL;
+	while (*str == ' ')
+		str = str+1;
+	while (*str && str[strlen  (str)-1] == ' ')
+		str[strlen (str)-1] = 0;
+	return str;
+}
+
+
 icalparser* icalparser_new(void)
 {
     struct icalparser_impl* impl = 0;
@@ -809,6 +821,7 @@ icalcomponent* icalparser_add_line(icalparser* parser,
 	}
 
 	str = icalparser_get_next_parameter(end,&end);
+	str = strstrip (str);
 
 	if (str != 0){
 	    char* name;
@@ -848,7 +861,7 @@ icalcomponent* icalparser_add_line(icalparser* parser,
 			     ICAL_XLICERRORTYPE_PARAMETERNAMEPARSEERROR);
 		tail = 0;
 		parser->state = ICALPARSER_ERROR;
-		return 0;
+		continue;
 	    }
 
 	    if (param == 0){
@@ -888,7 +901,7 @@ icalcomponent* icalparser_add_line(icalparser* parser,
 		    icalparameter_free(param);
 		    tail = 0;
 		    parser->state = ICALPARSER_ERROR;
-		    return 0;
+		    continue;	
 		} 
 	    }
 
@@ -915,6 +928,7 @@ icalcomponent* icalparser_add_line(icalparser* parser,
     vcount=0;
     while(1) {
 	str = icalparser_get_next_value(end,&end, value_kind);
+	str = strstrip (str);
 
 	if (str != 0){
 		
