@@ -26,13 +26,15 @@
 #endif
 
 #include <stdio.h>
-#include <glib.h>
 #include <pthread.h>
 
-#include "camel-exception.h"
-#include "libedataserver/e-memory.h"
+#include <glib.h>
+#include <glib/gi18n-lib.h>
+
+#include <libedataserver/e-memory.h>
 
 #include "camel-debug.h"
+#include "camel-exception.h"
 
 /* dont turn this off */
 #define w(x) x
@@ -155,12 +157,10 @@ camel_exception_free (CamelException *exception)
  * simply returns.
  **/
 void
-camel_exception_set (CamelException *ex,
-		     ExceptionId id,
-		     const char *desc)
+camel_exception_set (CamelException *ex, ExceptionId id, const char *desc)
 {
 	if (camel_debug("exception"))
-		printf("CamelException.set(%p, %d, '%s')\n", ex, id, desc);
+		printf("CamelException.set(%p, %u, '%s')\n", ex, id, desc);
 
 	if (!ex)
 		return;
@@ -198,10 +198,7 @@ camel_exception_set (CamelException *ex,
  * simply returns.
  **/
 void
-camel_exception_setv (CamelException *ex,
-		      ExceptionId id,
-		      const char *format, 
-		      ...)
+camel_exception_setv (CamelException *ex, ExceptionId id, const char *format, ...)
 {
 	va_list args;
 	char *desc;
@@ -211,7 +208,7 @@ camel_exception_setv (CamelException *ex,
 	va_end (args);
 
 	if (camel_debug("exception"))
-		printf("CamelException.setv(%p, %d, '%s')\n", ex, id, desc);
+		printf("CamelException.setv(%p, %u, '%s')\n", ex, id, desc);
 	
 	if (!ex) {
 		g_free(desc);
@@ -303,6 +300,6 @@ camel_exception_get_description (CamelException *ex)
 		ret = ex->desc;
 	else
 		w(g_warning ("camel_exception_get_description called with NULL parameter."));
-		
-	return ret;
+
+	return ret ? ret : (_("No description available"));
 }
