@@ -4,7 +4,7 @@
  *  Authors: Michael Zucchi <notzed@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -12,26 +12,26 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
 
-/** WARNING
- **
- ** DO NOT USE THIS CODE OUTSIDE OF CAMEL
- **
- ** IT IS SUBJECT TO CHANGE OR MAY VANISH AT ANY TIME
- **/
-
-#include "camel-html-parser.h"
+/* WARNING
+ *
+ * DO NOT USE THIS CODE OUTSIDE OF CAMEL
+ *
+ * IT IS SUBJECT TO CHANGE OR MAY VANISH AT ANY TIME
+ */
 
+#include <ctype.h>
 #include <stdio.h>
 #include <string.h>
 
-#include <glib/gunicode.h>
-#include <ctype.h>
+#include <glib.h>
+
+#include "camel-html-parser.h"
 
 /* if defined, must also compile in dump_tag() below somewhere */
 #define d(x)
@@ -749,7 +749,7 @@ static int tokenise_step(CamelHTMLParserPrivate *p, char **datap, int *lenp)
 					g_string_append_c(p->values->pdata[p->attr], ';');
 				} else {
 					d(printf("got entity: %s = %s\n", p->ent->str, p->ent_utf8));
-					g_string_append(p->values->pdata[p->attr], p->ent_utf8);
+					g_string_append_len(p->values->pdata[p->attr], p->ent_utf8, len);
 				}
 			} else if (isalnum(c) || c=='#') { /* FIXME: right type */
 				g_string_append_c(p->ent, c);
