@@ -28,12 +28,12 @@
 #endif
 
 #include <ctype.h>
+#include <errno.h>
 #include <stdio.h>
 #include <string.h>
-#include <errno.h>
 
-#include "libedataserver/e-iconv.h"
-#include "libedataserver/e-time-utils.h"
+#include <libedataserver/e-iconv.h>
+#include <libedataserver/e-time-utils.h>
 
 #include "camel-mime-filter-bestenc.h"
 #include "camel-mime-filter-charset.h"
