@@ -26,13 +26,14 @@
 
 #include <config.h>
 
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <errno.h>
 
 #include <glib.h>
+#include <glib/gi18n-lib.h>
 #include <glib/gstdio.h>
 
 #include "camel/camel-debug.h"
@@ -40,7 +41,6 @@
 #include "camel/camel-exception.h"
 #include "camel/camel-file-utils.h"
 #include "camel/camel-folder.h"
-#include "camel/camel-i18n.h"
 #include "camel/camel-net-utils.h"
 #include "camel/camel-private.h"
 #include "camel/camel-sasl.h"
@@ -63,10 +63,6 @@
 #include "camel-imap-summary.h"
 #include "camel-imap-utils.h"
 
-#if !GLIB_CHECK_VERSION (2, 8, 0)
-#define g_access access
-#endif
-
 #define d(x) 
 
 /* Specified in RFC 2060 */
@@ -1136,6 +1132,18 @@ imap_forget_folder (CamelImapStore *imap_store, const char *folder_name, CamelEx
 		g_free (folder_dir);
 		goto event;
 	}
+	camel_object_unref (summary);
+
+	g_unlink (summary_file);
+	g_free (summary_file);
+
+	summary_file = g_strdup_printf ("%s/summary-meta", folder_dir);
+	summary = camel_imap_summary_new (NULL, summary_file);
+	if (!summary) {
+		g_free (summary_file);
+		g_free (folder_dir);
+		goto event;
+	}
 	
 	cache = camel_imap_message_cache_new (folder_dir, summary, ex);
 	if (cache)
