@@ -4,7 +4,7 @@
  *  Authors: Michael Zucchi <notzed@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -12,7 +12,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
@@ -30,6 +30,8 @@
 #define CAMEL_LOCAL_SUMMARY_CLASS(klass) CAMEL_CHECK_CLASS_CAST (klass, camel_local_summary_get_type (), CamelLocalSummaryClass)
 #define CAMEL_IS_LOCAL_SUMMARY(obj)      CAMEL_CHECK_TYPE (obj, camel_local_summary_get_type ())
 
+G_BEGIN_DECLS
+
 typedef struct _CamelLocalSummary      CamelLocalSummary;
 typedef struct _CamelLocalSummaryClass CamelLocalSummaryClass;
 
@@ -92,5 +94,6 @@ int camel_local_summary_decode_x_evolution(CamelLocalSummary *cls, const char *x
 /* utility functions - write headers to a file with optional X-Evolution header and/or status header */
 int camel_local_summary_write_headers(int fd, struct _camel_header_raw *header, const char *xevline, const char *status, const char *xstatus);
 
-#endif /* ! _CAMEL_LOCAL_SUMMARY_H */
+G_END_DECLS
 
+#endif /* ! _CAMEL_LOCAL_SUMMARY_H */
