@@ -26,11 +26,12 @@
 #include <config.h>
 #endif
 
+#include <glib/gi18n-lib.h>
+
 #include "camel-provider.h"
 #include "camel-sendmail-transport.h"
 #include "camel-session.h"
 #include "camel-url.h"
-#include "camel-i18n.h"
 
 static CamelProvider sendmail_provider = {
 	"sendmail",
