@@ -8,15 +8,15 @@
  * Copyright 2000 Ximian, Inc. (www.ximian.com)
  *
  * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU General Public 
+ * modify it under the terms of version 2 of the GNU Lesser General Public 
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -29,18 +29,19 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <signal.h>
-#include <sys/wait.h>
-#include <unistd.h>
 #include <string.h>
+#include <unistd.h>
+#include <sys/wait.h>
+
+#include <glib/gi18n-lib.h>
 
-#include "camel-sendmail-transport.h"
-#include "camel-mime-filter-crlf.h"
-#include "camel-stream-filter.h"
-#include "camel-mime-message.h"
 #include "camel-data-wrapper.h"
-#include "camel-stream-fs.h"
 #include "camel-exception.h"
-#include "camel-i18n.h"
+#include "camel-mime-filter-crlf.h"
+#include "camel-mime-message.h"
+#include "camel-sendmail-transport.h"
+#include "camel-stream-filter.h"
+#include "camel-stream-fs.h"
 
 static char *get_name (CamelService *service, gboolean brief);
 
@@ -128,7 +129,7 @@ sendmail_send_to (CamelTransport *transport, CamelMimeMessage *message,
 	header = (struct _camel_header_raw *) &CAMEL_MIME_PART (message)->headers;
 	n = header->next;
 	while (n != NULL) {
-		if (!strcasecmp (n->name, "Bcc")) {
+		if (!g_ascii_strcasecmp (n->name, "Bcc")) {
 			header->next = n->next;
 			tail->next = n;
 			n->next = NULL;
@@ -166,6 +167,8 @@ sendmail_send_to (CamelTransport *transport, CamelMimeMessage *message,
 				      _("Could not fork sendmail: "
 					"%s: mail not sent"),
 				      g_strerror (errno));
+		close (fd[0]);
+		close (fd[1]);
 		sigprocmask (SIG_SETMASK, &omask, NULL);
 		g_free (argv);
 		
