@@ -23,7 +23,6 @@
 
 #include "e-account-list.h"
 #include "e-account.h"
-#include "e-data-server-marshal.h"
 
 #include <string.h>
 
@@ -62,7 +61,7 @@ e_account_list_class_init (EAccountListClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (EAccountListClass, account_added),
 			      NULL, NULL,
-			      e_data_server_marshal_NONE__OBJECT,
+			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE, 1,
 			      E_TYPE_ACCOUNT);
 	signals[ACCOUNT_CHANGED] =
@@ -71,7 +70,7 @@ e_account_list_class_init (EAccountListClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (EAccountListClass, account_changed),
 			      NULL, NULL,
-			      e_data_server_marshal_NONE__OBJECT,
+			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE, 1,
 			      E_TYPE_ACCOUNT);
 	signals[ACCOUNT_REMOVED] =
@@ -80,7 +79,7 @@ e_account_list_class_init (EAccountListClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (EAccountListClass, account_removed),
 			      NULL, NULL,
-			      e_data_server_marshal_NONE__OBJECT,
+			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE, 1,
 			      E_TYPE_ACCOUNT);
 }
@@ -292,6 +291,46 @@ e_account_list_save (EAccountList *account_list)
 	gconf_client_suggest_sync (account_list->priv->gconf, NULL);
 }
 
+void 
+e_account_list_prune_proxies (EAccountList *account_list)
+{
+	EAccount *account;
+	EIterator *iter;
+	
+	for (iter = e_list_get_iterator (E_LIST (account_list));
+	     e_iterator_is_valid (iter);
+	     e_iterator_next (iter)) {
+		account = (EAccount *)e_iterator_get (iter);
+		if (account->parent_uid) 
+			e_account_list_remove (account_list, account);
+	}
+
+	e_account_list_save (account_list);
+	g_object_unref (iter);
+}
+
+void 
+e_account_list_remove_account_proxies (EAccountList *accounts, EAccount *account)
+{
+	EAccount *child_account;
+
+	while ( (child_account = (EAccount *)e_account_list_find (accounts, E_ACCOUNT_FIND_PARENT_UID, account->uid))) {
+		e_account_list_remove (accounts, child_account);
+		child_account = NULL;
+	}
+
+	e_account_list_save (accounts);
+}
+
+int
+e_account_list_account_has_proxies (EAccountList *accounts, EAccount *account)
+{
+	if (e_account_list_find (accounts, E_ACCOUNT_FIND_PARENT_UID, account->uid))
+		return TRUE;
+
+	return FALSE;
+}
+
 /**
  * e_account_list_add:
  * @accounts: 
@@ -451,6 +490,10 @@ e_account_list_find(EAccountList *accounts, e_account_find_t type, const char *k
 			if (account->id)
 				found = g_ascii_strcasecmp(account->id->address, key) == 0;
 			break;
+		case E_ACCOUNT_FIND_PARENT_UID:
+			if (account->parent_uid)
+				found = strcmp(account->parent_uid, key) == 0;
+			break;
 		}
 
 		if (found)
